@@ -10,13 +10,14 @@ it to :func:`invoke.Collection.from_module`.
 
 import os
 import sys
+import io
 import glob
 import time
 import datetime
 from datetime import timedelta
 import shutil
 
-from atelier.utils import i2d
+from atelier.utils import i2d, i2t
 from babel.dates import format_date
 import rstgen
 from atelier.projects import load_projects
@@ -73,13 +74,13 @@ def local(*args, **kwargs):  # probably no longer used
 
 
 def get_current_date(today=None):
-    """
-    """
-
     if today is None:
         # return datetime.datetime.utcnow()
-        return datetime.date.today()
-    return i2d(today)
+        return (datetime.date.today(), datetime.datetime.now())
+    parts = today.split(":")
+    if len(parts) == 1:
+        return (i2d(today), datetime.datetime.now())
+    return (i2d(parts[0]), i2t(parts[1]))
 
 
 def set_times(pth):
@@ -89,15 +90,20 @@ def set_times(pth):
 
     """
     mtime = time.time()
-    os.utime(pth, (mtime, mtime))
+    try:
+        os.utime(pth, (mtime, mtime))
+    except FileNotFoundError:
+        raise FileNotFoundError("No such file: {}".format(pth))
 
 
 def rmtree_after_confirm(p, batch=False):
     if not p.exists():
         # print("20210425 does not exist:", str(p))
         return
-    if batch or confirm(
-            "OK to remove %s and everything under it?" % p.absolute()):
+    what = "Remove %s and everything under it" % p.absolute()
+    if batch or confirm("OK to {}?".format(what)):
+        if batch:
+            print(what)
         shutil.rmtree(p)
 
 
@@ -194,6 +200,14 @@ class MissingConfig(Exception):
         Exception.__init__(self, msg)
 
 
+@task(name='updatefixtures')
+def update_fixtures(ctx):
+    # print(ctx.languages)
+    if ctx.fixtures_updater:
+        ctx.fixtures_updater(ctx)
+    # m = import_module(ctx.fixtures_updater)
+    # m.update_fixtures(ctx)
+
 @task(name='test')
 def run_tests(ctx):
     """Run the test suite of this project."""
@@ -254,12 +268,10 @@ def build_docs(ctx, only=None):
     """Build docs. Build all Sphinx HTML doctrees for this project. """
     # print("Build docs for {}".format(atelier.current_project))
 
-    # cmd = ctx.build_docs_command
-    # if cmd:
-    #     print("-" * 80)
-    #     print("Run build_docs_command {0} :".format(cmd))
-    #     ctx.run(cmd, pty=True)
-    # else:
+    cmd = ctx.make_docs_command
+    if cmd:
+        print("Invoking make_docs_command {0}".format(cmd))
+        ctx.run(cmd, pty=True)
     for tree in atelier.current_project.get_doc_trees():
         if tree.src_path:
            if only is None or tree.rel_path == only:
@@ -293,11 +305,14 @@ def setup_sdist(ctx):
 
 
 @task(name='release', help={
+    'batch': "Don't ask for confirmations.",
     'branch': "Create a version branch."})
-def pypi_release(ctx, branch=False):
+def pypi_release(ctx, batch=False, branch=False):
     """
     Publish a new version to PyPI.
-    See https://lino-framework.gitlab.io/atelier/invlib.html for details.
+
+    See https://atelier.lino-framework.org/invlib.html#command-inv-release
+    for details.
 
     """
     atelier.current_project.load_info()
@@ -312,7 +327,8 @@ def pypi_release(ctx, branch=False):
     show_revision_status(ctx)
     show_pypi_status(ctx, True)
 
-    must_confirm(RELEASE_CONFIRM % info)
+    if not (batch or confirm(RELEASE_CONFIRM % info)):
+        return
 
     # args = [sys.executable, "setup.py"]
     # args += ["sdist", "--formats=gztar"]
@@ -418,8 +434,7 @@ def checkin(ctx, today=None):
 
     show_revision_status(ctx)
 
-    today = get_current_date(today)
-
+    today, now = get_current_date(today)
     entry = get_blog_entry(ctx, today)
     if not entry.path.exists():
         quit("%s does not exist!" % entry.path.absolute())
@@ -456,11 +471,17 @@ def edit_blog_entry(ctx, today=None):
 
                 $ inv blog -t 20150727
 
+            When :env:`multiple_blog_entries_per_day` is `True`::
+
+                $ inv blog -t 20150727:1232
+
     """
     if not ctx.editor_command:
         raise MissingConfig("editor_command")
-    today = get_current_date(today)
-    entry = get_blog_entry(ctx, today)
+    today, now = get_current_date(today)
+    if not ctx.multiple_blog_entries_per_day:
+        now = None
+    entry = get_blog_entry(ctx, today, now)
     if not entry.path.exists():
         if ctx.languages is None:
             # txt = today.strftime(ctx.long_date_format)
@@ -469,8 +490,11 @@ def edit_blog_entry(ctx, today=None):
             lng = ctx.languages[0]
         txt = format_date(today, format='full', locale=lng)
         txt = txt[0].upper() + txt[1:]  # estonian weekdays
-        content = rstgen.header(1, txt)
-        content = ":date: {0}\n\n".format(today) + content
+        if now is not None:
+            txt += " ({})".format(now.strftime("%H:%M"))
+            today = str(today) + " " + now.strftime("%H:%M")
+        content = ":date: {0}\n\n".format(today) + rstgen.header(1, txt)
+
         msg = "{0}\nCreate file {1}?".format(content, entry.path)
         if not confirm(msg):
             return
@@ -488,6 +512,10 @@ def edit_blog_entry(ctx, today=None):
         # touch the year's index for Sphinx:
         set_times(entry.path.parent / 'index.rst')
 
+        # Touch the main index.rst in case it contains a blogger_latest directive.
+        # We assume that if there is one, it is there.
+        set_times(Path(ctx.blog_root) / 'index.rst')
+
     args = [ctx.editor_command.format(entry.path)]
     args += [str(entry.path)]
     # raise Exception("20160324 %s", args)
@@ -556,12 +584,16 @@ def show_pypi_status(ctx, severe=True):
                 "released." % info)
 
 
-def get_blog_entry(ctx, today):
+def get_blog_entry(ctx, today, now=None):
     """Return an RstFile object representing the blog entry for that date
     in the current project.
 
     """
-    parts = ('blog', str(today.year), today.strftime("%m%d"))
+    parts = ['blog', str(today.year)]
+    if now is None:
+        parts.append(today.strftime("%m%d"))
+    else:
+        parts.append(today.strftime("%m%d") + "_" + now.strftime("%H%M"))
     return RstFile(Path(ctx.blog_root), ctx.blogref_url, parts)
 
 
@@ -676,10 +708,10 @@ def check_config(ctx):
     if info['url'] != origin:
         print("url in SETUP_INFO ({}) differs from git origin {}".format(
             info['url'], origin))
-    srcref_url = getattr(prj.main_package, 'srcref_url', None)
-    if srcref_url and not srcref_url.startswith(origin):
-        print("srcref_url of {} ({}) must start with git origin ({})".format(
-            prj.main_package, srcref_url, origin))
+    # srcref_url = getattr(prj.main_package, 'srcref_url', None)
+    # if srcref_url and not srcref_url.startswith(origin):
+    #     print("srcref_url of {} ({}) must start with git origin ({})".format(
+    #         prj.main_package, srcref_url, origin))
 
     doc_trees = prj.get_xconfig('doc_trees')
     intersphinx_urls = prj.get_xconfig('intersphinx_urls')
@@ -714,7 +746,7 @@ def commited_today(ctx, today=None):
 
     list_options = dict()
     if True:
-        today = get_current_date(today)
+        today, now = get_current_date(today)
         ONEDAY = timedelta(days=1)
         yesterday = today - ONEDAY
         tomorrow = today + ONEDAY
@@ -776,7 +808,7 @@ def commited_today(ctx, today=None):
 
 from importlib import import_module
 
-def run_in_demo_projects(ctx, py_cmd, cov=False, bare=False):
+def run_in_demo_projects(ctx, py_cmd, cov=False, bare=False, out_stream=None):
     """
     Run the given Python command line `py_cmd` in each demo project.
 
@@ -799,14 +831,52 @@ def run_in_demo_projects(ctx, py_cmd, cov=False, bare=False):
             if not bare:
                 print("-" * 80)
                 print("Run in demo project {0}\n$ {1} :".format(dpname, cmd))
-            ctx.run(cmd, pty=True)
+            ctx.run(cmd, pty=True, out_stream=out_stream)
 
 
-@task(name='install')
-def configure(ctx):
-    """Run `manage.py install` on every demo project."""
-    cmd = 'manage.py install --noinput'
-    run_in_demo_projects(ctx, cmd, bare=True)
+@task(name='install', optional=['list', 'list_only'])
+def configure(ctx, list=False, list_only=False):
+    """
+
+    Run `manage.py install` on every demo project. Takes two optional boolean
+    flags `--list` and `--list-only` and are mutually exclusive meaning cannot
+    be used both at the same time.
+
+    :cmd:`inv install --list` installs the required packages and also lists and
+    writes them into :file:`requirements-install.txt`.
+
+    :cmd:`inv install --list-only` does not install the packages and only lists
+    and writes them into :file:`requirements-install.txt`.
+
+    """
+
+    def do_listing():
+        print("Getting the list of required packages from all of the demo projects.")
+        cmd = 'manage.py install --list'
+        temp_f = io.StringIO()
+        run_in_demo_projects(ctx, cmd, bare=True, out_stream=temp_f)
+        temp_f.seek(0)
+        cwd = os.getcwd()
+        with open(cwd + '/requirements-install.txt', 'w') as f:
+            f.write("\n".join(set(temp_f.read().split())))
+        with open(cwd + '/requirements.txt', 'r+') as f:
+            content = f.read()
+            include = '-r requirements-install.txt'
+            if include not in content:
+                content = include + '\n' + content
+                f.seek(0)
+                f.write(content)
+
+    def do_install():
+        cmd = 'manage.py install --noinput'
+        run_in_demo_projects(ctx, cmd, bare=True)
+
+    if list_only:
+        do_listing()
+    else:
+        if list:
+            do_listing()
+        do_install()
 
 
 @task(name='prep')
