@@ -7,13 +7,13 @@ See :doc:`/usage`.
 
 """
 import os
-
+import sys
+from rstgen.utils import cd
+# import getopt
+# from distutils.errors import DistutilsArgError
 # import pkg_resources
 from pathlib import Path
-try:
-    from importlib import import_module
-except ImportError:
-    from django.utils.importlib import import_module
+from importlib import import_module
 
 from atelier.invlib.utils import SphinxTree
 
@@ -24,6 +24,11 @@ _PROJECT_INFOS = []
 _PROJECTS_DICT = {}
 
 
+# class NullDevice():
+#     def write(self, s):
+#         pass
+
+
 def load_inv_namespace(root_dir):
     """
     Execute the :xfile:`tasks.py` file of this project and return its
@@ -41,13 +46,15 @@ def load_inv_namespace(root_dir):
     # https://stackoverflow.com/questions/67631/how-to-import-a-module-given-the-full-path
     # https://stackoverflow.com/questions/19009932/import-arbitrary-python-source-file-python-3-3
     # fqname = 'atelier.prj_%s' % self.index
-    cwd = Path().resolve()
-    os.chdir(root_dir)
     m = dict()
-    m["__file__"] = str(tasks_file)
-    with open(tasks_file) as f:
-        exec(f.read(), m)
-    os.chdir(cwd)
+    with cd(root_dir):
+        m["__file__"] = str(tasks_file)
+        try:
+            with open(tasks_file) as f:
+                exec(f.read(), m)
+        except Exception as e:
+            print("Error while loading {} : {}".format(tasks_file, e))
+            return
     return m['ns']
 
 
@@ -108,7 +115,7 @@ def get_project_from_path(root_dir):
         if (root_dir / 'tasks.py').exists():
             return add_project(root_dir)
         # E.g. when the module was instaled via pip
-        print("No project info in {}".format(root_dir))
+        print("No tasks.py file in {}".format(root_dir))
     return prj
 
 
@@ -117,57 +124,6 @@ def load_projects():
         yield p
 
 
-def get_setup_info(root_dir):
-    """
-    Return `SETUP_INFO` defined in the :xfile:`setup.py` file of the
-    specified `root_dir`.
-    """
-    setup_file = root_dir / 'setup.py'
-    if not setup_file.exists():
-        # print("20180118 no setup.py file in {}".format(root_dir.absolute()))
-        return {}
-        # raise RuntimeError(
-        #     "You must call 'inv' from a project's root directory.")
-    # sys.path.insert(0, root_dir)
-    # setup_module = __import__('setup')
-    # print 20140610, root_dir
-    # del sys.path[0]
-    # return getattr(setup_module, 'SETUP_INFO', None)
-    g = dict()
-    g['__name__'] = 'not_main'
-    # g['__file__'] = setup_file
-    cwd = Path().resolve()
-    os.chdir(root_dir)
-    with open("setup.py") as f:
-        code = compile(f.read(), "setup.py", 'exec')
-        try:
-            exec(code, g)
-        except SystemExit:
-            os.chdir(cwd)
-            raise Exception(
-                "Oops, {} called sys.exit().\n"
-                "Atelier requires the setup() call to be in a "
-                "\"if __name__ == '__main__':\" condition.".format(
-                    setup_file))
-    os.chdir(cwd)
-    info = g.get('SETUP_INFO')
-    if info is None:
-        raise Exception(
-            "Oops, {} doesn't define a name SETUP_INFO.".format(
-                setup_file))
-    return info
-
-    # # Expected to define global SETUP_INFO.
-    # # Note that main_package may be "sphinxcontrib.dailyblog"
-    # args = env.main_package.split('.')
-    # args.append('project_info.py')
-    # file =env.ROOTDIR / ('/'.join(args))
-    # with open(file) as f:
-    #    code = compile(f.read(), file, 'exec')
-    #    exec(code, globals())
-    # #execfile(env.ROOTDIR / ('/'.join(args)), globals())
-    # env.SETUP_INFO = SETUP_INFO
-
 
 class Project(object):
     """Represents a project.
@@ -191,6 +147,7 @@ class Project(object):
     # srcref_url = None
     # intersphinx_urls = {}
     SETUP_INFO = None
+    atelier_info = {}
     config = None
     inv_namespace = None
     _git_status = None
@@ -222,8 +179,11 @@ class Project(object):
             'revision_control_system': None,
             'apidoc_exclude_pathnames': [],
             'editor_command': os.environ.get('EDITOR'),
+            'fixtures_updater': None,
             'prep_command': "",
-            # 'build_docs_command': "",
+            'make_docs_command': "",
+            'docs_rsync_dest': "",
+            'rsync_command': "",
             'test_command': "python -m unittest discover -s tests",
             'demo_projects': [],
             'demo_prep_command': "manage.py prep --noinput --traceback",
@@ -234,12 +194,23 @@ class Project(object):
             'blog_root': root_dir / 'docs',
             'blogref_url': None,
             'long_date_format': "%Y%m%d (%A, %d %B %Y)",
+            'multiple_blog_entries_per_day': False,
             'sdist_dir': root_dir / 'dist',
             'pypi_dir': root_dir / '.pypi_cache',
             'use_dirhtml': False,
             'doc_trees': ['docs'],
             'intersphinx_urls': {},
         }
+        # --progress:  show progress
+        # --delete: delete files in dest
+        # --times:  preserve timestamps
+        # --times fails when several users can publish to the same server
+        # alternatively. Only the owner  can change the mtime of a
+        # directory, other users can't, even if they have write permission
+        # through the group.
+        self.config.update(
+            rsync_command = "rsync -e ssh -r --verbose --progress --delete "
+                "--times --omit-dir-times --exclude .doctrees ./ {dest_url}")
 
 
     def __repr__(self):
@@ -286,7 +257,7 @@ class Project(object):
             # load_info() has been called before
             return
 
-        self.SETUP_INFO = get_setup_info(self.root_dir)
+        self.load_setup_file()
 
         # if self.main_package is None:
         #     self.config.setdefault('doc_trees', ['docs'])
@@ -298,9 +269,42 @@ class Project(object):
             if ns is not None:
                 self.set_namespace(ns)
 
-
-        # if self.main_package is None:
-        #     self.config.update(doc_trees=['docs'])
+    def load_setup_file(self):
+        """
+        Load the :xfile:`setup.py` file if it exists.
+        """
+        setup_file = self.root_dir / 'setup.py'
+        if not setup_file.exists():
+            # print("20180118 no setup.py file in {}".format(root_dir.absolute()))
+            self.SETUP_INFO = {}
+            return
+        g = dict()
+        g['__name__'] = 'not_main'
+        sys.args = []
+        # sys.stdout = sys.stderr = NullDevice()
+        cwd = os.getcwd()
+        with cd(str(self.root_dir)):
+            with open("setup.py") as f:
+                code = compile(f.read(), "setup.py", 'exec')
+                try:
+                    exec(code, g)
+                # except (SystemExit, getopt.GetoptError, DistutilsArgError):
+                except SystemExit:
+                    # contextmanager doesn't restore cwd when we raise an
+                    # exception:
+                    os.chdir(cwd)
+                    raise Exception(
+                        "Oops, {} called sys.exit().\n"
+                        "Atelier requires the setup() call to be in a "
+                        "\"if __name__ == '__main__':\" condition.".format(
+                            setup_file))
+        info = g.get('SETUP_INFO')
+        if info is None:
+            raise Exception(
+                "Oops, {} doesn't define a name SETUP_INFO.".format(
+                    setup_file))
+        self.SETUP_INFO = info
+        self.atelier_info = g.get('ATELIER_INFO', {})
 
     def get_status(self):
         # if self.config['revision_control_system'] != 'git':
@@ -332,15 +336,14 @@ class Project(object):
 
         """
         self.load_info()
-        if self.inv_namespace is not None:
+        if name in self.atelier_info:
+            return self.atelier_info[name]
+        if self.inv_namespace is None:
+            default = self.config.get(name, default)
+        else:
             cfg = self.inv_namespace.configuration()
             default = cfg.get(name, default)
         if self.main_package:
-            # if name in cfg:
-            #     msg = "{} configures both {} and main_package. "
-            #     msg += "If you have a main_package then you must set "
-            #     msg += "doc_trees there."
-            #     raise Exception(msg.format(self, name))
             return getattr(self.main_package, name, default)
         return default
 
@@ -390,7 +393,7 @@ class Project(object):
 
         """
         intersphinx_urls = self.get_xconfig('intersphinx_urls', {})
-        return intersphinx_urls.get(dtname, "http://localhost")
+        return intersphinx_urls.get(dtname, "")
 
         # for dt in self.get_doc_trees():
         #     # print("20210426", self, repr(dt))
