@@ -7,7 +7,7 @@
 
 SETUP_INFO = dict(
     name='atelier',
-    version='1.1.44',
+    version='1.1.47',
     description="A collection of tools for software artists",
     license_files=['COPYING'],
     author='Rumma & Ko Ltd',
@@ -18,7 +18,7 @@ install_requires = ['invoke', 'argh', 'six',
                     'future', 'Babel',
                     'python-dateutil', 'Sphinx', 'rstgen']
 install_requires.append('requests')
-install_requires.append('sphinx-panels')
+install_requires.append('sphinx-design')
 install_requires.append('sphinx-rtd-theme')
 install_requires.append('pydata-sphinx-theme')
 install_requires.append('insipid-sphinx-theme')
@@ -47,18 +47,11 @@ SETUP_INFO.update(
 `atelier` is a collection of tools for managing and maintaining Python software
 projects.
 
-It contains:
+It contains a minimalistic project management and a library of `invoke
+<https://www.pyinvoke.org/>`_ commands.
 
-- some general Python utilities
-  (`atelier.utils <https://lino-framework.gitlab.io/atelier/api/atelier.utils.html>`_)
-- some Sphinx extensions
-  (`atelier.sphinxconf <https://lino-framework.gitlab.io/atelier/api/atelier.sphinxconf.html>`_)
-- a library of invoke commands
-  (`atelier.invlib <https://lino-framework.gitlab.io/atelier/api/atelier.invlib.html>`_)
-- a minimalistic project management
-  (`atelier.projects <https://lino-framework.gitlab.io/atelier/api/atelier.projects.html>`_)
-
-The central project homepage is https://lino-framework.gitlab.io/atelier
+- Source code: https://gitlab.com/lino-framework/atelier
+- Documentation: https://lino-framework.gitlab.io/atelier
 
 """,
     classifiers="""\
@@ -73,16 +66,14 @@ Operating System :: OS Independent""".splitlines())
 
 SETUP_INFO.update(packages=[n for n in """
 atelier
-atelier.sphinxconf
-atelier.sphinxconf.languages
 atelier.invlib
 atelier.cli
 """.splitlines() if n])
 
-SETUP_INFO.update(
-    zip_safe=False,
-    include_package_data=True)
-
+# SETUP_INFO.update(
+#     zip_safe=False,
+#     include_package_data=True)
+#
 # SETUP_INFO.update(package_data=dict())
 #
 # def add_package_data(package, *patterns):
@@ -90,4 +81,4 @@ SETUP_INFO.update(
 #     l.extend(patterns)
 #     return l
 #
-# add_package_data('atelier.sphinxconf', '*.html')
+# add_package_data('rstgen.sphinxconf', '*.html')
