@@ -23,14 +23,3 @@ class BasicTests(TestCase):
 class PackagesTests(TestCase):
     def test_packages(self):
         self.run_packages_test(SETUP_INFO['packages'])
-
-
-class SphinxTests(TestCase):
-    def test_sphinxconf(self):
-        self.run_simple_doctests('atelier/sphinxconf/__init__.py')
-
-    def test_base(self):
-        self.run_simple_doctests('atelier/sphinxconf/base.py')
-
-    def test_sigal(self):
-        self.run_simple_doctests('atelier/sphinxconf/sigal_image.py')
